==> qmmp_1.4.3.orig.tar.bz2: qmmp-1.4.3/src/plugins/Engines/mplayer/translations/mplayer_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="33"/>
        <source>Mplayer Plugin</source>
        <translation>Mplayer-liitännäinen</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="36"/>
        <source>Video Files</source>
        <translation>Videotiedostot</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="83"/>
        <source>About MPlayer Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="86"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Toteuttanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="39"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="39"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="65"/>
        <source>Demuxer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="67"/>
        <source>Video format</source>
        <translation>Videomuoto</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="68"/>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="69"/>
        <source>Video codec</source>
        <translation>Videokoodekki</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="70"/>
        <source>Aspect ratio</source>
        <translation>Kuvasuhde</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="71"/>
        <source>Video bitrate</source>
        <translation>Videon bittinopeus</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="71"/>
        <location filename="../mplayermetadatamodel.cpp" line="76"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="74"/>
        <source>Audio codec</source>
        <translation>Äänikoodekki</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Sample rate</source>
        <translation>Näytteenottotaajuus</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="76"/>
        <source>Audio bitrate</source>
        <translation>Äänen bittinopeus</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Channels</source>
        <translation>Kanavat</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="72"/>
        <source>Resolution</source>
        <translation>Resoluutio</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>MPlayer-asetukset</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>Ääni:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation>Lisävalinnat:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>oletus</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Engines/mplayer/translations/mplayer_plugin_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="33"/>
        <source>Mplayer Plugin</source>
        <translation>Mplayer Plugin</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="36"/>
        <source>Video Files</source>
        <translation>Videotiedostot</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="74"/>
        <source>About MPlayer Plugin</source>
        <translation>Tietoja: MPlayer Plugin</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="75"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>Qmmp MPlayer Plugin</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="76"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>Tämä laajennus käyttää tausta-ohjelmana MPlayeria</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="77"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Kirjoittanut: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="56"/>
        <source>Demuxer</source>
        <translation>Demuxer</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="58"/>
        <source>Video format</source>
        <translation>Videomuoto</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="59"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="60"/>
        <source>Video codec</source>
        <translation>Videokoodekki</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="61"/>
        <source>Aspect ratio</source>
        <translation>Kuvasuhde</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="62"/>
        <source>Video bitrate</source>
        <translation>Videon bittinopeus</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="62"/>
        <location filename="../mplayermetadatamodel.cpp" line="66"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="64"/>
        <source>Audio codec</source>
        <translation>Äänikoodekki</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="65"/>
        <source>Sample rate</source>
        <translation>Taajuus</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="65"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="66"/>
        <source>Audio bitrate</source>
        <translation>Äänen bittinopeus</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="67"/>
        <source>Channels</source>
        <translation>Kanavat</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="63"/>
        <source>Resolution</source>
        <translation>Resoluutio</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>Asetukset MPlayer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>Ääni:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation>Äänen/videon automaattinen synkronointi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation>Vahvistuskerroin:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation>Lisävalinnat:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation>Lisävalinnat komentoriville</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>oletus</translation>
    </message>
</context>
</TS>
